@@ -5,7 +5,7 @@
 This module contains the core functionality for twtcher. The main object
 here is the TwitcherObject which acts as a simple wrapper for each watch.
 
-Author: Brady Catherman (brady@twitter.com)
+Author: Brady Catherman (github@gecka.us)
 """
 
 import grp
