@@ -6,7 +6,7 @@ This class contains the main "Twitcher" object which is a simple wrapper for
 the main loop functionality. It catches SIGCHLD, and manages the select loop.
 It also creates the top level zookeeper and config directory watcher objects.
 
-Author: Brady Catherman (brady@twitter.com)
+Author: Brady Catherman (github@gecka.us)
 """
 
 import errno
